@@ -6,12 +6,12 @@ Simple waveform generator widget, with plotting.
 from dataclasses import dataclass, field
 from enum import Enum
 from functools import partial
+from typing import Annotated
 
 import matplotlib.pyplot as plt
 import numpy as np
 from matplotlib.backends.backend_qt5agg import FigureCanvas
 from scipy import signal
-from typing_extensions import Annotated
 
 from magicgui import magicgui, register_type, widgets
 
