@@ -8,15 +8,13 @@ import sys
 import types
 import typing
 import warnings
-from contextlib import contextmanager
 from importlib import import_module
 from importlib.machinery import ModuleSpec
 from itertools import count
 from textwrap import dedent
-from typing import TYPE_CHECKING, Any, Mapping
+from typing import TYPE_CHECKING, Any
 
-from griffe.dataclasses import Alias
-from griffe.docstrings import numpy
+from griffe import Alias
 from mkdocstrings_handlers.python.handler import PythonHandler
 
 from magicgui.type_map import get_widget_class
@@ -24,20 +22,11 @@ from magicgui.type_map import get_widget_class
 warnings.simplefilter("ignore", DeprecationWarning)
 
 if TYPE_CHECKING:
+    from collections.abc import Mapping
+
     from mkdocs.structure.pages import Page
 
 
-# TODO: figure out how to do this with options
-@contextmanager
-def _hide_numpy_warn():
-    if not hasattr(numpy, "_warn"):
-        yield
-        return
-    before, numpy._warn = numpy._warn, lambda *x, **k: None
-    yield
-    numpy._warn = before
-
-
 def inject_dynamic_docstring(item: Alias, identifier: str) -> None:
     for i in range(1, 3):
         module_name, *names = identifier.rsplit(".", 1)
@@ -67,12 +56,11 @@ class WidgetHandler(PythonHandler):
         return item
 
     def render(self, data: Any, config: Mapping[str, Any]) -> str:
-        with _hide_numpy_warn():
-            return super().render(data, config)
+        return super().render(data, config)
 
 
 class MyLoader(importlib.abc.Loader):
-    def create_module(self, spec):
+    def create_module(self, spec) -> types.ModuleType:
         return types.ModuleType(spec.name)
 
     def exec_module(self, module: types.ModuleType) -> None:
@@ -123,6 +111,8 @@ def _replace_autosummary(md: str) -> str:
         if name:
             module, _name = name.rsplit(".", 1)
             obj = getattr(import_module(module), _name)
+            if obj.__doc__ is None:
+                raise ValueError(f"Missing docstring for {obj}")
             table.append(f"| [`{_name}`][{name}] | {obj.__doc__.splitlines()[0]} |")
     lines[start:last_line] = table
     return "\n".join(lines)
