@@ -5,7 +5,6 @@ from .widgets import (
     Container,
     DateEdit,
     DateTimeEdit,
-    EmptyWidget,
     FloatSlider,
     FloatSpinBox,
     Label,
@@ -32,9 +31,7 @@ __all__ = [
     "ComboBox",
     "Container",
     "DateEdit",
-    "TimeEdit",
     "DateTimeEdit",
-    "EmptyWidget",
     "FloatSlider",
     "FloatSpinBox",
     "Label",
@@ -47,6 +44,7 @@ __all__ = [
     "Slider",
     "SpinBox",
     "TextEdit",
+    "TimeEdit",
     "ToolBar",
     "get_text_width",
     "show_file_dialog",
