@@ -6,7 +6,6 @@ from .widgets import (
     DateEdit,
     DateTimeEdit,
     Dialog,
-    EmptyWidget,
     FloatRangeSlider,
     FloatSlider,
     FloatSpinBox,
@@ -41,11 +40,9 @@ __all__ = [
     "DateEdit",
     "DateTimeEdit",
     "Dialog",
-    "EmptyWidget",
     "FloatRangeSlider",
     "FloatSlider",
     "FloatSpinBox",
-    "get_text_width",
     "Image",
     "Label",
     "LineEdit",
@@ -59,11 +56,12 @@ __all__ = [
     "RadioButtons",
     "RangeSlider",
     "Select",
-    "show_file_dialog",
     "Slider",
     "SpinBox",
     "Table",
     "TextEdit",
     "TimeEdit",
     "ToolBar",
+    "get_text_width",
+    "show_file_dialog",
 ]
