@@ -4,6 +4,6 @@ Note: these are not guaranteed to be stable. Names and parameters may change or
 removed in future releases. Use at your own risk.
 """
 
-from .schema._guiclass import button, guiclass, is_guiclass
+from .schema._guiclass import GuiBuilder, button, guiclass, is_guiclass
 
-__all__ = ["button", "guiclass", "is_guiclass"]
+__all__ = ["GuiBuilder", "button", "guiclass", "is_guiclass"]
