@@ -388,8 +388,7 @@ class ScalarMappable:
                 if xx.dtype.kind == "f":
                     if norm and (xx.max() > 1 or xx.min() < 0):
                         raise ValueError(
-                            "Floating point image RGB values "
-                            "must be in the 0..1 range."
+                            "Floating point image RGB values must be in the 0..1 range."
                         )
                     if bytes:
                         xx = (xx * 255).astype(np.uint8)
@@ -545,7 +544,7 @@ class Image(ScalarMappable):
             self._A.dtype, float, "same_kind"
         ):
             raise TypeError(
-                f"Image data of dtype {self._A.dtype} cannot be converted to " "float"
+                f"Image data of dtype {self._A.dtype} cannot be converted to float"
             )
 
         if self._A.ndim == 3 and self._A.shape[-1] == 1:
@@ -599,7 +598,7 @@ class Image(ScalarMappable):
         """
         if A is None:
             raise RuntimeError(
-                "You must first set the image " "array or the image attribute"
+                "You must first set the image array or the image attribute"
             )
         if A.size == 0:
             raise RuntimeError(
