@@ -1,10 +1,7 @@
-import sys
 import typing
 from collections.abc import Mapping, Sequence
 from concurrent.futures import Future
 
-import pytest
-
 from magicgui._util import safe_issubclass
 
 
@@ -48,7 +45,6 @@ class TestSafeIsSubclass:
         assert safe_issubclass(typing.Dict[int, str], typing.Mapping)
         assert safe_issubclass(typing.Dict[int, str], Mapping)
 
-    @pytest.mark.skipif(sys.version_info < (3, 9), reason="PEP-585 is supported in 3.9+")
     def test_typing_builtins_list(self):
         assert safe_issubclass(list[int], list)
         assert safe_issubclass(list[int], Sequence)
@@ -58,7 +54,6 @@ class TestSafeIsSubclass:
         assert safe_issubclass(typing.List[int], list)
         assert safe_issubclass(typing.List[int], list[int])
 
-    @pytest.mark.skipif(sys.version_info < (3, 9), reason="PEP-585 is supported in 3.9+")
     def test_typing_builtins_dict(self):
         assert safe_issubclass(dict[int, str], dict)
         assert safe_issubclass(dict[int, str], Mapping)
@@ -80,9 +75,17 @@ class TestSafeIsSubclass:
         assert not safe_issubclass(typing.Tuple[int, int], typing.Tuple[int, str])
         assert not safe_issubclass(typing.Tuple[int, int], typing.Tuple[int, int, int])
 
-    @pytest.mark.skipif(sys.version_info < (3, 9), reason="Future[] is supported in 3.9+")
     def test_subclass_future(self):
-        assert safe_issubclass(Future[typing.List[int]], Future[list[int]])
-        assert safe_issubclass(Future[typing.List[int]], Future[list])
-        assert safe_issubclass(Future[list[int]], Future[typing.List[int]])
-        assert not safe_issubclass(Future[list[int]], Future[typing.List[str]])
+        assert safe_issubclass(Future[list[int]], Future[list[int]])
+        assert safe_issubclass(Future[list[int]], Future[list])
+        assert safe_issubclass(Future[list[int]], Future[list[int]])
+        assert not safe_issubclass(Future[list[int]], Future[list[str]])
+
+    def test_subclass_new_type(self):
+        new_int = typing.NewType("new_int", int)
+
+        assert safe_issubclass(new_int, new_int)
+        assert safe_issubclass(list[new_int], typing.List[new_int])
+        assert safe_issubclass(typing.List[new_int], list[new_int])
+        assert safe_issubclass(list[new_int], typing.Sequence[new_int])
+        assert safe_issubclass(list[new_int], list[new_int])
